@@ -1,5 +1,5 @@
 package Apache::Debug;
-use Cwd 'fastcwd';
+
 #from HTTP::Status
 my %StatusCode = (
     100 => 'Continue',
@@ -23,22 +23,18 @@ my %StatusCode = (
     403 => 'Forbidden',
     404 => 'Not Found',
     405 => 'Method Not Allowed',
-    406 => 'Not Acceptable',
+    406 => 'None Acceptable',
     407 => 'Proxy Authentication Required',
     408 => 'Request Timeout',
     409 => 'Conflict',
     410 => 'Gone',
     411 => 'Length Required',
-    412 => 'Precondition Failed',
-    413 => 'Request Entity Too Large',
-    414 => 'Request-URI Too Large',
-    415 => 'Unsupported Media Type',
+    412 => 'Unless True',
     500 => 'Internal Server Error',
     501 => 'Not Implemented',
     502 => 'Bad Gateway',
     503 => 'Service Unavailable',
     504 => 'Gateway Timeout',
-    505 => 'HTTP Version Not Supported',
 );
 
 sub dump {
@@ -47,72 +43,56 @@ sub dump {
     my $conn = $r->connection;
     my %headers = $r->headers_in;
     my $host = $r->get_remote_host;
-    my $cwd = fastcwd;
-    $r->status($status);
-    $r->content_type("text/html");
-    $r->content_language("en");
-    $r->no_cache(1);
-    $r->header_out("X-Debug-Version" => q$Id: Debug.pm,v 1.15 1997/05/12 22:04:01 dougm Exp $);
-    $r->send_http_header;
-    
-    return 0 if $r->header_only;   # should not generate a body
 
+    $r->content_type("text/html");
+    $r->header_out("Status",$status);
+    $r->send_http_header;
+
+    my $args = $r->args;
+    my(%args,%in);
     my $title = "$status $StatusCode{$status}";
     $r->write_client(join("\n", "<html>",
 			  "<head><title>$title</title></head>",
                           "<body>", "<h3>$title</h3>", @_, 
-			  "<pre>", ($@ ? "$@\n" : ""), "cwd=$cwd\n"));
-
+			  "<pre>", ($@ ? "$@\n" : "")));
     for (
 	 qw(
-	    method uri protocol path_info filename
-            allow_options
+	    method uri protocol path_info filename 
 	    )
 	 )
     {
-	$r->print(sprintf "<b>\$r->%-17s</b> : %s\n", $_, $r->$_() );
+	$r->write_client("$_ : ", $r->$_(), "\n");
     }
-
     for (
 	 qw(
 	    server_admin 
-	    server_hostname
-            port
+	    server_hostname port
 	    )
 	 ) 
     {
-	$r->print(sprintf "<b>\$s->%-17s</b> : %s\n", $_, $srv->$_() );
+	$r->write_client("$_ : ", $srv->$_(), "\n");
     }
-
     for (
 	 qw(
-	    remote_host
-            remote_ip
-            remote_logname
-            user
-            auth_type
+	    remote_host remote_ip
 	    )
 	 )
     {
-	$r->print(sprintf "<b>\$c->%-17s</b> : %s\n", $_, $conn->$_() );
+	$r->write_client("$_ : ", $conn->$_(), "\n");
     }
-
-    my $args = $r->args;
-    my %args = $r->args;
-    my %in   = $r->content;
-    $r->print(
-		     "\n<b>scalar \$r->args       :</b> $args\n",
+    $r->write_client(
+		     "\nscalar \$r->args:\n $args\n",
 			 
-		     "\n<b>\$r->args:</b>\n",
-		     (map { "   $_ = $args{$_}\n" } sort keys %args),
-
-		     "\n<b>\$r->content:</b>\n",
-		     (map { "   $_ = $in{$_}\n" } sort keys %in),
+		     "\n\$r->args:\n",		     
+		     (map { "$_ = $args{$_}\n" } keys %args),
 			 
-		     "\n<b>\$r->headers_in:</b>\n",		     
-		     (map { sprintf "   %-12s = %s\n", $_, $headers{$_} } sort keys %headers),
+		     "\n\$r->content:\n",		     
+		     (map { "$_ = $in{$_}\n" } keys %in),
+			 
+		     "\n\$r->headers_in:\n",		     
+		     (map { "$_ = $headers{$_}\n" } keys %headers),
 		     );
-    $r->print("</pre>\n</body></html>\n");
+    $r->write_client("</pre>\n</body></html>");
     return 0; #need to give a return status
 }
 
@@ -126,9 +106,9 @@ Apache::Debug - Utilities for debugging embedded perl code
 
 =head1 SYNOPSIS
 
-    use Apache::Debug ();
+    require Apache::Debug;
 
-    Apache::Debug::dump($r, SERVER_ERROR, "Uh Oh!");
+    Apache::Debug::dump(Apache->request, 500, "Uh Oh!");
 
 =head1 DESCRIPTION
 
